@@ -90,7 +90,7 @@ where
 
     source_chain::genesis(
         workspace.vault.clone(),
-        workspace.dht_env.clone(),
+        workspace.dht_db.clone(),
         api.keystore().clone(),
         dna_file.dna_hash().clone(),
         agent_pubkey,
@@ -104,16 +104,13 @@ where
 /// The workspace for Genesis
 pub struct GenesisWorkspace {
     vault: DbWrite<DbKindAuthored>,
-    dht_env: DbWrite<DbKindDht>,
+    dht_db: DbWrite<DbKindDht>,
 }
 
 impl GenesisWorkspace {
     /// Constructor
-    pub fn new(env: DbWrite<DbKindAuthored>, dht_env: DbWrite<DbKindDht>) -> WorkspaceResult<Self> {
-        Ok(Self {
-            vault: env,
-            dht_env,
-        })
+    pub fn new(env: DbWrite<DbKindAuthored>, dht_db: DbWrite<DbKindDht>) -> WorkspaceResult<Self> {
+        Ok(Self { vault: env, dht_db })
     }
 
     pub async fn has_genesis(&self, author: AgentPubKey) -> DatabaseResult<bool> {
@@ -148,8 +145,8 @@ pub mod tests {
 
     use crate::conductor::api::MockCellConductorApi;
     use crate::core::ribosome::MockRibosomeT;
-    use holochain_state::prelude::test_dht_env;
-    use holochain_state::{prelude::test_authored_env, source_chain::SourceChain};
+    use holochain_state::prelude::test_dht_db;
+    use holochain_state::{prelude::test_authored_db, source_chain::SourceChain};
     use holochain_types::test_utils::fake_agent_pubkey_1;
     use holochain_types::test_utils::fake_dna_file;
     use holochain_zome_types::Header;
@@ -159,15 +156,15 @@ pub mod tests {
     #[tokio::test(flavor = "multi_thread")]
     async fn genesis_initializes_source_chain() {
         observability::test_run().unwrap();
-        let test_env = test_authored_env();
-        let dht_env = test_dht_env();
+        let test_db = test_authored_db();
+        let dht_db = test_dht_db();
         let keystore = test_keystore();
-        let vault = test_env.env();
+        let vault = test_db.to_db();
         let dna = fake_dna_file("a");
         let author = fake_agent_pubkey_1();
 
         {
-            let workspace = GenesisWorkspace::new(vault.clone().into(), dht_env.env()).unwrap();
+            let workspace = GenesisWorkspace::new(vault.clone().into(), dht_db.to_db()).unwrap();
             let mut api = MockCellConductorApi::new();
             api.expect_sync_dpki_request()
                 .returning(|_, _| Ok("mocked dpki request response".to_string()));
@@ -187,7 +184,7 @@ pub mod tests {
 
         {
             let source_chain =
-                SourceChain::new(vault.clone(), dht_env.env(), keystore, author.clone())
+                SourceChain::new(vault.clone(), dht_db.to_db(), keystore, author.clone())
                     .await
                     .unwrap();
             let headers = source_chain
